@@ -719,6 +719,8 @@ void resolveRule(LoaderState &state, Item *item, ProjectContext *projectContext,
         rule->requiresInputs = rule->declaresInputs();
     rule->auxiliaryInputs
         = evaluator.fileTagsValue(item, StringConstants::auxiliaryInputsProperty());
+    rule->auxiliaryInputsFromDependencies = evaluator.fileTagsValue(
+        item, StringConstants::auxiliaryInputsFromDependenciesProperty());
     rule->excludedInputs
         = evaluator.fileTagsValue(item, StringConstants::excludedInputsProperty());
     if (rule->excludedInputs.empty()) {
@@ -820,10 +822,10 @@ bool ProductContext::dependenciesResolvingPending() const
             && !product && !delayedError.hasError();
 }
 
-std::pair<ProductDependency, ProductContext *> ProductContext::pendingDependency() const
+std::pair<ProductDependencyType, ProductContext *> ProductContext::pendingDependency() const
 {
     return dependenciesContext ? dependenciesContext->pendingDependency()
-                               : std::make_pair(ProductDependency::None, nullptr);
+                               : std::make_pair(ProductDependencyType::None, nullptr);
 }
 
 TimingData &TimingData::operator+=(const TimingData &other)
